xquery version "3.1" encoding "UTF-8";

declare namespace rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#";
declare namespace marc21="http://www.loc.gov/MARC21/slim";
declare namespace owl="http://www.w3.org/2002/07/owl#";
declare namespace rdaGr2="http://rdvocab.info/ElementsGr2/";
declare namespace bf="http://bibframe.org/vocab/";
declare namespace http="http://expath.org/ns/http-client";

declare option exist:serialize "method=json media-type=application/json";

import module namespace config="https://sade.textgrid.de/ns/config" at "../../modules/config.xqm";
import module namespace console="http://exist-db.org/xquery/console";

let $id := request:get-parameter("id", "")
let $objUri := "http://textgridrep.de/" || $id
let $doc := collection($config:app-root || "/textgrid/rdf/")//rdf:Description[@rdf:about eq $objUri]
let $uri := ($doc//owl:sameAs)[1]/@rdf:resource/string()
let $inst := $doc//bf:instanceOf


let $opac :=
    if($inst and contains($uri, "gateway-bayern"))
        then concat("http://lod.b3kat.de/title/", substring-after($uri, "http://gateway-bayern.de/"), "?output=xml")
    else if($inst)
        then $uri
    else
        ""


let $target :=
    if (matches($uri, "d-nb"))
    (: we use marcxml instead of rdfxml in this case since all information needed
    is available in plain text in marcxml. in rdfxml it would be necessary to
    query the database again (for each place of activity and occupation), which
    leads to a severe drop in performance :)
        then concat($uri, "/about/marcxml")
    else if(matches($uri, "http://thesaurus.cerl.org/record/"))
        (: trick 17 mit Proxy:)
        then replace($uri, "http://thesaurus.cerl.org/record/", "http://bdn-edition.de/cerl/rdf.pl?rid=")
    else if(matches($uri, "https://thesaurus.cerl.org/record/"))
        then replace($uri, "https://thesaurus.cerl.org/record/", "http://bdn-edition.de/cerl/rdf.pl?rid=")
    else()

let $req :=
    if($target)
        then <http:request href="{$target}" method="get">
                <http:header name="Connection" value="close" />
           </http:request>
    else()
let $result :=
    if($req)
        then http:send-request($req)[2]
    else()


(: ###########
 : ### GND ###
 : ###########:)

let $datafield := $result//marc21:datafield


(: marc21:datafield[@tag = "100"] -- Heading Personal Name
 : marc21:datafield[@tag = "100"]/marc21:subfield[@code = "a"] -- Personal name
 : marc21:datafield[@tag = "100"]/marc21:subfield[@code = "d"] -- Dates associated with a name
 :
 : marc21:datafield[@tag = "551"] -- See Also From Tracing-Geographic Name
 : marc21:datafield[@tag = "551"]/marc21:subfield[@code = "a"] -- Geographic name
 : marc21:datafield[@tag = "551"]/marc21:subfield[@code = "i"] -- Relationship information
 : The GND uses this datafield to denote the places of birth and death of a person.:)


let $namePath := $datafield[@tag = "100"]/marc21:subfield[@code = "a"]/string()
let $namePath := $namePath || " " || $datafield[@tag = "100"]/marc21:subfield[@code = "c"]/string()
let $namePath := replace($namePath, "&#152;", "")
let $namePath := replace($namePath, "&#156;", "")
let $name :=
    if(contains($namePath, ",")) then
        let $forename := substring-after($namePath, ",")
        let $surname := substring-before($namePath, ",")
        return normalize-unicode($forename || " " || $surname)
    else normalize-unicode($namePath)


let $placeOfBirthTmp := $datafield[@tag = "551"][child::marc21:subfield[@code = "i"]/string() = "Geburtsort"]
let $placeOfBirth :=
    if($placeOfBirthTmp)
        then normalize-unicode(concat("in ", $placeOfBirthTmp/marc21:subfield[@code = "a"]/string()))
    else ""
let $dates := $datafield[@tag = "100"]/marc21:subfield[@code = "d"]/string()
let $dateOfBirth :=
    if(contains($dates, "-") and contains(substring-before($dates, "-"), "v"))
        then concat("*&#8201;", substring-before(replace($dates, "v", ""), "-"), " v. Chr. ", $placeOfBirth)
    else if(contains($dates, "-"))
        then concat("*&#8201;", substring-before($dates, "-"), " ", $placeOfBirth)
    else ""


let $placeOfDeathTmp := $datafield[@tag = "551"][child::marc21:subfield[@code = "i"]/string() = "Sterbeort"]
let $placeOfDeath :=
    if($placeOfDeathTmp)
        then normalize-unicode(concat("in ", $placeOfDeathTmp/marc21:subfield[@code = "a"]/string()))
    else ""
let $deathTmp := substring-after($dates, "-")
let $dateOfDeath :=
    if(contains($dates, "-") and contains($deathTmp, "v") and string-length($deathTmp) != 0)
        then concat("†&#8202;", substring-after(replace($dates, "v", ""), "-"), " v. Chr. ", $placeOfDeath)
    else if(contains($dates, "-") and string-length($deathTmp) != 0)
        then concat("†&#8202;", $deathTmp, " ", $placeOfDeath)
    else ""

let $periodOfLife :=
    if($dateOfBirth = "" and $dateOfDeath = "")
        then $dates
    else ""


(: marc21:datafield[@tag = "550"] -- See Also From Tracing-Topical Term
 : marc21:datafield[@tag = "550"]/marc21:subfield[@code = "a"] -- Topical term or geographic name entry element
 : marc21:datafield[@tag = "678"] -- Biographical or Historical Data
 : marc21:datafield[@tag = "678"]/marc21:subfield[@code = "b"] -- Expansion
 : The GND uses this datafield to denote a person"s occupation. :)

let $profession := $datafield[@tag = "550"][contains(child::marc21:subfield[@code = "i"], "Beruf")]
let $occupationArray :=
    if($profession)
        then $profession/marc21:subfield[@code = "a"]/string()
    else if($datafield[@tag = "678"])
        then $datafield[@tag = "678"]/marc21:subfield[@code = "b"]/string()
    else ""
let $occupations :=
    if(string-join($occupationArray, ", ") != "")
        then normalize-unicode(string-join(distinct-values($occupationArray), ", "))
    else
        ""


(: marc21:datafield[@tag = "551"] -- See Also From Tracing-Geographic Name
 : marc21:datafield[@tag = "551"]/marc21:subfield[@code = "a"] -- Geographic name
 : marc21:datafield[@tag = "551"]/marc21:subfield[@code = "i"] -- Relationship information
 : The GND uses this datafield to denote the workplace(s) of a person. :)

let $workplaceArray := $datafield[@tag = "551"][child::marc21:subfield[@code = "i"]/string() = "Wirkungsort"]/marc21:subfield[@code = "a"]/string()
let $workplaces :=
    if(string-join($workplaceArray, ", ") != "")
        then normalize-unicode(string-join(distinct-values($workplaceArray), ", "))
    else
        ""
return
    <data>
        <person>
            <dnb>
                <name>{$name}</name>
                <dateOfBirth>{$dateOfBirth}{$periodOfLife}</dateOfBirth>
                <dateOfDeath>{$dateOfDeath}</dateOfDeath>
                <occupation>{$occupations}</occupation>
                <place>{$workplaces}</place>
            </dnb>
        </person>
        <uri>{$uri}</uri>
        <book>
            <opac>{$opac}</opac>
        </book>
    </data>
